@@ -41,8 +41,8 @@ def decode_response_body(response):
     """
     Decodes the JSON-format response body
 
-    Arguments
-    ---------
+    Parameters
+    ----------
     response: tornado.httpclient.HTTPResponse
 
     Returns
@@ -54,6 +54,7 @@ def decode_response_body(response):
         body = codecs.decode(response.body, 'ascii')
     except Exception:
         body = codecs.decode(response.body, 'utf-8')
+    body = re.sub("\'", '\\"', body)
     body = re.sub('"', '\"', body)
     body = re.sub("'", '"', body)
     body = json.loads(body)
@@ -123,8 +124,8 @@ class OAuthLoginHandler(tornado.web.RequestHandler, OAuth2Mixin):
         """
         Fetches the authenticated user
 
-        Arguments
-        ---------
+        Parameters
+        ----------
         redirect_uri: (str)
           The OAuth redirect URI
         client_id: (str)
@@ -171,8 +172,8 @@ class OAuthLoginHandler(tornado.web.RequestHandler, OAuth2Mixin):
         """
         Fetches the access token.
 
-        Arguments
-        ---------
+        Parameters
+        ----------
         client_id:
           The client ID
         redirect_uri:
@@ -450,10 +451,17 @@ class OAuthLoginHandler(tornado.web.RequestHandler, OAuth2Mixin):
             log.warning(f"{provider} OAuth provider failed to fully "
                         f"authenticate returning the following response:"
                         f"{body}.")
+        if hasattr(body, "get"):
+            log_message = body.get('error_description', str(body))
+            reason = body.get('error', 'Unknown error')
+        else:
+            log_message = str(response)
+            reason = 'Unknown Error'
+
         raise HTTPError(
             status,
-            body.get('error_description', str(body)),
-            reason=body.get('error', 'Unknown error')
+            log_message=log_message,
+            reason=reason
         )
 
     def write_error(self, status_code, **kwargs):
@@ -1184,6 +1192,26 @@ class OAuthProvider(BasicAuthProvider):
             del state._oauth_user_overrides[user]
 
 
+class PAMLoginHandler(BasicLoginHandler):
+    """
+    A LoginHandler that authenticates users via PAM.
+    """
+
+    def _validate(self, username, password):
+        try:
+            import pamela
+        except ImportError as e:
+            log.error(
+                "PAM authentication requires the pamela package. Please install it with e.g. 'pip install pamela'"
+            )
+            raise e
+        try:
+            pamela.authenticate(username, password)
+        except pamela.PAMError:
+            return False
+        return True
+
+
 AUTH_PROVIDERS = {
     'auth0': Auth0Handler,
     'azure': AzureAdLoginHandler,
@@ -1195,7 +1223,8 @@ AUTH_PROVIDERS = {
     'gitlab': GitLabLoginHandler,
     'okta': OktaLoginHandler,
     'password': PasswordLoginHandler,
-    'auth_code': CodeChallengeLoginHandler
+    'auth_code': CodeChallengeLoginHandler,
+    'pam': PAMLoginHandler,
 }
 
 # Populate AUTH Providers from external extensions
