@@ -34,6 +34,7 @@ from ..util import to_async_gen
 from ..viewable import Children
 from ..widgets import Widget
 from ..widgets.button import Button
+from ._param import CallbackException
 from .icon import ChatReactionIcons
 from .message import ChatMessage
 from .step import ChatStep
@@ -100,13 +101,16 @@ class ChatFeed(ListPanel):
         the previous message value `contents`, the previous `user` name,
         and the component `instance`.""")
 
-    callback_exception = param.Selector(
-        default="summary", objects=["raise", "summary", "verbose", "ignore"], doc="""
+    callback_exception = CallbackException(
+        default="summary", allow_refs=False, doc="""
         How to handle exceptions raised by the callback.
         If "raise", the exception will be raised.
         If "summary", a summary will be sent to the chat feed.
-        If "verbose", the full traceback will be sent to the chat feed.
+        If "verbose" or "traceback", the full traceback will be sent to the chat feed.
         If "ignore", the exception will be ignored.
+        If a callable is provided, the signature must contain the
+        `exception` and `instance` arguments and it
+        will be called with the exception.
         """)
 
     callback_user = param.String(default="Assistant", doc="""
@@ -118,6 +122,11 @@ class ChatFeed(ListPanel):
         defaults to the avatar set in `ChatMessage.default_avatars` if matching key exists.
         Otherwise defaults to the first character of the `callback_user`.""")
 
+    edit_callback = param.Callable(allow_refs=False, doc="""
+        Callback to execute when a user edits a message.
+        The signature must include the new message value `contents`,
+        the `message_index`, and the `instance`.""")
+
     card_params = param.Dict(default={}, doc="""
         Params to pass to Card, like `header`, `header_background`, `header_color`, etc.""")
 
@@ -159,7 +168,11 @@ class ChatFeed(ListPanel):
         The text to display next to the placeholder icon.""")
 
     placeholder_params = param.Dict(default={
-        "user": " ", "reaction_icons": {}, "show_copy_icon": False, "show_timestamp": False
+        "user": " ",
+        "reaction_icons": {},
+        "show_copy_icon": False,
+        "show_timestamp": False,
+        "show_edit_icon": False
     }, doc="""
         Params to pass to the placeholder ChatMessage, like `reaction_icons`,
         `timestamp_format`, `show_avatar`, `show_user`, `show_timestamp`.
@@ -232,7 +245,16 @@ class ChatFeed(ListPanel):
         super().__init__(*objects, **params)
 
         if self.help_text:
-            self.objects = [ChatMessage(self.help_text, user="Help", **message_params), *self.objects]
+            self.objects = [
+                ChatMessage(
+                    self.help_text,
+                    user="Help",
+                    show_edit_icon=False,
+                    show_copy_icon=False,
+                    show_reaction_icons=False,
+                    **message_params
+                ), *self.objects
+            ]
 
         # instantiate the card's column
         linked_params = dict(
@@ -368,6 +390,17 @@ class ChatFeed(ListPanel):
             except ValueError:
                 pass
 
+    async def _on_edit_message(self, event):
+        if self.edit_callback is None:
+            return
+        message = event.obj
+        contents = message.serialize()
+        index = self._chat_log.index(message)
+        if iscoroutinefunction(self.edit_callback):
+            await self.edit_callback(contents, index, self)
+        else:
+            self.edit_callback(contents, index, self)
+
     def _build_message(
         self,
         value: dict,
@@ -396,7 +429,15 @@ class ChatFeed(ListPanel):
             message_params["width"] = int(self.width - 80)
         message_params.update(input_message_params)
 
+        if "show_edit_icon" not in message_params:
+            user = message_params.get("user", "")
+            message_params["show_edit_icon"] = (
+                bool(self.edit_callback) and
+                (isinstance(user, str) and user.lower() not in (self.callback_user.lower(), "help"))
+            )
+
         message = ChatMessage(**message_params)
+        message.param.watch(self._on_edit_message, "edited")
         return message
 
     def _upsert_message(
@@ -574,13 +615,18 @@ class ChatFeed(ListPanel):
             self._callback_state = CallbackState.STOPPED
         except Exception as e:
             send_kwargs: dict[str, Any] = dict(user="Exception", respond=False)
-            if self.callback_exception == "summary":
+            if callable(self.callback_exception):
+                if iscoroutinefunction(self.callback_exception):
+                    await self.callback_exception(e, self)
+                else:
+                    self.callback_exception(e, self)
+            elif self.callback_exception == "summary":
                 self.send(
                     f"Encountered `{e!r}`. "
                     f"Set `callback_exception='verbose'` to see the full traceback.",
                     **send_kwargs
                 )
-            elif self.callback_exception == "verbose":
+            elif self.callback_exception in ("verbose", "traceback"):
                 self.send(f"```python\n{traceback.format_exc()}\n```", **send_kwargs)
             elif self.callback_exception == "ignore":
                 return
@@ -613,8 +659,8 @@ class ChatFeed(ListPanel):
 
         If `respond` is `True`, additionally executes the callback, if provided.
 
-        Arguments
-        ---------
+        Parameters
+        ----------
         value : ChatMessage | dict | Any
             The message contents to send.
         user : str | None
@@ -665,8 +711,8 @@ class ChatFeed(ListPanel):
         This method is primarily for outputs that are not generators--
         notably LangChain. For most cases, use the send method instead.
 
-        Arguments
-        ---------
+        Parameters
+        ----------
         value : str | dict | ChatMessage
             The new token value to stream.
         user : str | None
@@ -704,6 +750,7 @@ class ChatFeed(ListPanel):
 
             if message_params:
                 message.param.update(**message_params)
+            self._chat_log.scroll_to_latest(scroll_limit=self.auto_scroll_limit)
             return message
 
         if isinstance(value, ChatMessage):
@@ -715,6 +762,7 @@ class ChatFeed(ListPanel):
         self._replace_placeholder(message)
 
         self.param.trigger("_post_hook_trigger")
+        self._chat_log.scroll_to_latest(scroll_limit=self.auto_scroll_limit)
         return message
 
     def add_step(
@@ -733,8 +781,8 @@ class ChatFeed(ListPanel):
         Adds a ChatStep component either by appending it to an existing
         ChatMessage or creating a new ChatMessage.
 
-        Arguments
-        ---------
+        Parameters
+        ----------
         step : str | list(str) | ChatStep | None
             The objects to stream to the step.
         append : bool
@@ -778,6 +826,8 @@ class ChatFeed(ListPanel):
                 step_params["context_exception"] = self.callback_exception
             step = ChatStep(**step_params)
 
+        step._instance = self
+
         if append:
             for i in range(1, last_messages + 1):
                 if not self._chat_log:
@@ -822,7 +872,7 @@ class ChatFeed(ListPanel):
             self.stream(steps_layout, user=user or self.callback_user, avatar=avatar)
         else:
             steps_layout.append(step)
-            self._chat_log.scroll_to_latest()
+            self._chat_log.scroll_to_latest(scroll_limit=self.auto_scroll_limit)
         return step
 
     def prompt_user(
@@ -839,8 +889,8 @@ class ChatFeed(ListPanel):
         """
         Prompts the user to interact with a form component.
 
-        Arguments
-        ---------
+        Parameters
+        ----------
         component : Widget | ListPanel
             The component to prompt the user with.
         callback : Callable
@@ -1042,8 +1092,8 @@ class ChatFeed(ListPanel):
         """
         Exports the chat log.
 
-        Arguments
-        ---------
+        Parameters
+        ----------
         format : str
             The format to export the chat log as; currently only
             supports "transformers".
@@ -1105,8 +1155,8 @@ class ChatFeed(ListPanel):
         Iterates over the ChatInterface and any potential children in the
         applying the selector.
 
-        Arguments
-        ---------
+        Parameters
+        ----------
         selector: type or callable or None
           The selector allows selecting a subset of Viewables by
           declaring a type or callable function to filter by.
