@@ -362,11 +362,11 @@ class ChatInterface(ChatFeed):
         self._input_layout = input_layout
 
     def _wrap_callbacks(
-            self,
-            callback: Callable | None = None,
-            post_callback: Callable | None = None,
-            name: str = ""
-        ):
+        self,
+        callback: Callable | None = None,
+        post_callback: Callable | None = None,
+        name: str = ""
+    ):
         """
         Wrap the callback and post callback around the default callback.
         """
@@ -583,8 +583,8 @@ class ChatInterface(ChatFeed):
         """
         Set the active input widget tab index.
 
-        Arguments
-        ---------
+        Parameters
+        ----------
         index : int
             The active index to set.
         """
@@ -602,8 +602,8 @@ class ChatInterface(ChatFeed):
         """
         Exports the chat log for use with transformers.
 
-        Arguments
-        ---------
+        Parameters
+        ----------
         messages : list(ChatMessage)
             A list of ChatMessage objects to serialize.
         role_names : dict(str, str | list(str)) | None
@@ -654,7 +654,6 @@ class ChatInterface(ChatFeed):
         await super()._cleanup_response()
         await self._update_input_disabled()
 
-
     def send(
         self,
         value: ChatMessage | dict | Any,
@@ -669,8 +668,8 @@ class ChatInterface(ChatFeed):
 
         If `respond` is `True`, additionally executes the callback, if provided.
 
-        Arguments
-        ---------
+        Parameters
+        ----------
         value : ChatMessage | dict | Any
             The message contents to send.
         user : str | None
@@ -693,6 +692,8 @@ class ChatInterface(ChatFeed):
                 user = self.user
             if avatar is None:
                 avatar = self.avatar
+        message_params["show_edit_icon"] = message_params.get(
+            "show_edit_icon", user == self.user and self.edit_callback is not None)
         return super().send(value, user=user, avatar=avatar, respond=respond, **message_params)
 
     def stream(
@@ -713,8 +714,8 @@ class ChatInterface(ChatFeed):
         This method is primarily for outputs that are not generators--
         notably LangChain. For most cases, use the send method instead.
 
-        Arguments
-        ---------
+        Parameters
+        ----------
         value : str | dict | ChatMessage
             The new token value to stream.
         user : str | None
@@ -739,4 +740,5 @@ class ChatInterface(ChatFeed):
             # so only set to the default when not a ChatMessage
             user = user or self.user
             avatar = avatar or self.avatar
+        message_params["show_edit_icon"] = message_params.get("show_edit_icon", user == self.user and self.edit_callback is not None)
         return super().stream(value, user=user, avatar=avatar, message=message, replace=replace, **message_params)
