@@ -1,6 +1,9 @@
 from __future__ import annotations
 
+import sys
+
 from functools import partial
+from typing import Any
 from weakref import WeakKeyDictionary
 
 import bokeh
@@ -35,6 +38,26 @@ class Parameterized(bokeh.core.property.bases.Property):
         raise ValueError(msg)
 
 
+class PolarsDataFrame(bokeh.core.property.bases.Property):
+    """ Accept Polars DataFrame values.
+
+    This property only exists to support type validation, e.g. for "accepts"
+    clauses. It is not serializable itself, and is not useful to add to
+    Bokeh models directly.
+
+    """
+
+    def validate(self, value: Any, detail: bool = True) -> None:
+        super().validate(value, detail)
+
+        import polars as pl
+        if isinstance(value, (pl.DataFrame, pl.LazyFrame)):
+            return
+
+        msg = "" if not detail else f"expected Pandas DataFrame, got {value!r}"
+        raise ValueError(msg)
+
+
 class ParameterizedList(bokeh.core.property.bases.Property):
     """ Accept a list of Parameterized objects.
 
@@ -88,6 +111,15 @@ def bytes_param(p, kwargs):
     kwargs['default'] = None
     return bp.Nullable(bp.Bytes, **kwargs)
 
+def df_to_dict(df):
+    if 'polars' in sys.modules:
+        import polars as pl
+        if isinstance(df, pl.LazyFrame):
+            df = df.collect()
+        if isinstance(df, pl.DataFrame):
+            df = df.to_pandas()
+    return ColumnDataSource._data_from_df(df)
+
 PARAM_MAPPING = {
     pm.Array: lambda p, kwargs: bp.Array(bp.Any, **kwargs),
     pm.Boolean: lambda p, kwargs: bp.Bool(**kwargs),
@@ -98,7 +130,7 @@ PARAM_MAPPING = {
     pm.Color: color_param_to_ppt,
     pm.DataFrame: lambda p, kwargs: (
         bp.ColumnData(bp.Any, bp.Seq(bp.Any), **kwargs),
-        [(bp.PandasDataFrame, lambda x: ColumnDataSource._data_from_df(x))]
+        [(bp.PandasDataFrame, df_to_dict), (PolarsDataFrame, df_to_dict)]
     ),
     pm.DateRange: lambda p, kwargs: bp.Tuple(bp.Datetime, bp.Datetime, **kwargs),
     pm.Date: lambda p, kwargs: bp.Datetime(**kwargs),
@@ -121,8 +153,8 @@ def construct_data_model(parameterized, name=None, ignore=[], types={}, extras={
     Dynamically creates a Bokeh DataModel class from a Parameterized
     object.
 
-    Arguments
-    ---------
+    Parameters
+    ----------
     parameterized: param.Parameterized
         The Parameterized class or instance from which to create the
         DataModel
@@ -155,7 +187,8 @@ def construct_data_model(parameterized, name=None, ignore=[], types={}, extras={
         if pname == 'name' or pname is None:
             continue
         nullable = getattr(p, 'allow_None', False)
-        kwargs = {'default': p.default, 'help': p.doc}
+        default = p.default
+        kwargs = {'default': default, 'help': p.doc}
         if prop is None:
             bk_prop, accepts = bp.Any(**kwargs), []
         else:
@@ -163,9 +196,14 @@ def construct_data_model(parameterized, name=None, ignore=[], types={}, extras={
             bk_prop, accepts = bkp if isinstance(bkp, tuple) else (bkp, [])
             if nullable:
                 bk_prop = bp.Nullable(bk_prop, **kwargs)
+        is_valid = bk_prop.is_valid(default)
         for bkp, convert in accepts:
             bk_prop = bk_prop.accepts(bkp, convert)
         properties[pname] = bk_prop
+        if not is_valid:
+            for tp, converter in bk_prop.alternatives:
+                if tp.is_valid(default):
+                    bk_prop._default = default = converter(default)
     for pname, ptype in extras.items():
         if issubclass(ptype, pm.Parameter):
             ptype = PARAM_MAPPING.get(ptype)(None, {})
@@ -179,8 +217,8 @@ def create_linked_datamodel(obj, root=None):
     Creates a Bokeh DataModel from a Parameterized class or instance
     which automatically links the parameters bi-directionally.
 
-    Arguments
-    ---------
+    Parameters
+    ----------
     obj: param.Parameterized
        The Parameterized class to create a linked DataModel for.
 
