@@ -12,6 +12,7 @@ import os
 import pathlib
 import signal
 import sys
+import threading
 import uuid
 
 from collections.abc import Callable, Mapping
@@ -107,9 +108,11 @@ def _origin_url(url: str) -> str:
 
 def _server_url(url: str, port: int) -> str:
     if url.startswith("http"):
-        return '%s:%d%s' % (url.rsplit(':', 1)[0], port, "/")
+        return f"{url.rsplit(':', 1)[0]}:{port}/"
     else:
-        return 'http://%s:%d%s' % (url.split(':')[0], port, "/")
+        return f"http://{url.split(':')[0]}:{port}/"
+
+_tasks = set()
 
 def async_execute(func: Callable[..., None]) -> None:
     """
@@ -117,13 +120,29 @@ def async_execute(func: Callable[..., None]) -> None:
     is propagated from function to partial wrapping it.
     """
     if not state.curdoc or not state.curdoc.session_context:
-        ioloop = IOLoop.current()
-        event_loop = ioloop.asyncio_loop # type: ignore
-        wrapper = state._handle_exception_wrapper(func)
-        if event_loop.is_running():
-            ioloop.add_callback(wrapper)
+        try:
+            loop = asyncio.get_running_loop()
+        except RuntimeError:
+            loop = asyncio.new_event_loop()
+            asyncio.set_event_loop(loop)
+        # Avoid creating IOLoop if one is not already associated
+        # with the asyncio loop or we're on a child thread
+        if hasattr(IOLoop, '_ioloop_for_asyncio') and loop in IOLoop._ioloop_for_asyncio:
+            ioloop = IOLoop._ioloop_for_asyncio[loop]
+        elif threading.current_thread() is not threading.main_thread():
+            ioloop = IOLoop.current()
         else:
-            event_loop.run_until_complete(wrapper())
+            ioloop = None
+        wrapper = state._handle_exception_wrapper(func)
+        if loop.is_running():
+            if ioloop is None:
+                task = asyncio.ensure_future(wrapper())
+                _tasks.add(task)
+                task.add_done_callback(_tasks.discard)
+            else:
+                ioloop.add_callback(wrapper)
+        else:
+            loop.run_until_complete(wrapper())
         return
 
     if isinstance(func, partial) and hasattr(func.func, 'lock'):
@@ -182,8 +201,8 @@ def html_page_for_render_items(
     """
     Render an HTML page from a template and Bokeh render items.
 
-    Arguments
-    ---------
+    Parameters
+    ----------
     bundle (tuple):
         A tuple containing (bokehjs, bokehcss)
     docs_json (JSON-like):
@@ -249,7 +268,8 @@ def server_html_page_for_session(
 
     # ALERT: Replace with better approach before Bokeh 3.x compatible release
     if resources.mode == 'server':
-        dist_url = f'{state.rel_path}/{LOCAL_DIST}' if state.rel_path else LOCAL_DIST
+        with set_curdoc(session.document):
+            dist_url = f'{state.rel_path}/{LOCAL_DIST}' if state.rel_path else LOCAL_DIST
     else:
         dist_url = CDN_DIST
 
@@ -715,8 +735,8 @@ def serve(
 
     Reference: https://panel.holoviz.org/user_guide/Server_Configuration.html#serving-multiple-apps
 
-    Arguments
-    ---------
+    Parameters
+    ----------
     panels: Viewable, function or {str: Viewable or function}
       A Panel object, a function returning a Panel object or a
       dictionary mapping from the URL slug to either.
@@ -854,8 +874,8 @@ def get_server(
     Returns a Server instance with this panel attached as the root
     app.
 
-    Arguments
-    ---------
+    Parameters
+    ----------
     panel: Viewable, function or {str: Viewable}
       A Panel object, a function returning a Panel object or a
       dictionary mapping from the URL slug to either.
