@@ -203,11 +203,18 @@ class Feed(Column):
             # reset the buffers and loaded objects
             self.load_buffer = load_buffer
 
-    def scroll_to_latest(self):
+    def scroll_to_latest(self, scroll_limit: float | None = None) -> None:
         """
         Scrolls the Feed to the latest entry.
+
+        Parameters
+        ----------
+        scroll_limit : float, optional
+            Maximum pixel distance from the latest object in the Feed to
+            trigger scrolling. If the distance exceeds this limit, scrolling will not occur.
+            If this is not set, it will always scroll to the latest while setting this to 0 disables scrolling.
         """
         rerender = self._last_synced and self._last_synced[-1] < len(self.objects)
         if rerender:
             self._process_event()
-        self._send_event(ScrollLatestEvent, rerender=rerender)
+        self._send_event(ScrollLatestEvent, rerender=rerender, scroll_limit=scroll_limit)
