@@ -79,18 +79,17 @@ export class CardView extends ColumnView {
 
     let header_el
     if (this.model.collapsible) {
-      this.button_el = DOM.createElement("button", {type: "button", class: header_css_classes})
-      const icon = DOM.createElement("div", {class: button_css_classes})
+      this.button_el = DOM.button({class: header_css_classes})
+      const icon = DOM.div({class: button_css_classes})
       icon.innerHTML = this.model.collapsed ? CHEVRON_RIGHT : CHEVRON_DOWN
       this.button_el.appendChild(icon)
       this.button_el.style.backgroundColor = header_background != null ? header_background : ""
       header.el.style.backgroundColor = header_background != null ? header_background : ""
       this.button_el.appendChild(header.el)
-
-      this.button_el.onclick = () => this._toggle_button()
+      this.button_el.addEventListener("click", (e: MouseEvent) => this._toggle_button(e))
       header_el = this.button_el
     } else {
-      header_el = DOM.createElement((header_tag as any), {class: header_css_classes})
+      header_el = DOM.create_element((header_tag as any), {class: header_css_classes})
       header_el.style.backgroundColor = header_background != null ? header_background : ""
       header_el.appendChild(header.el)
     }
@@ -120,7 +119,12 @@ export class CardView extends ColumnView {
     this.invalidate_layout()
   }
 
-  _toggle_button(): void {
+  _toggle_button(e: MouseEvent): void {
+    for (const path of e.composedPath()) {
+      if (path instanceof HTMLInputElement) {
+        return
+      }
+    }
     this.model.collapsed = !this.model.collapsed
   }
 
@@ -148,8 +152,8 @@ export class CardView extends ColumnView {
     this.invalidate_layout()
   }
 
-  protected override _createElement(): HTMLElement {
-    return DOM.createElement((this.model.tag as any), {class: this.css_classes()})
+  protected override _create_element(): HTMLElement {
+    return DOM.create_element((this.model.tag as any), {class: this.css_classes()})
   }
 }
 
