@@ -6,8 +6,9 @@ from __future__ import annotations
 import os
 
 from base64 import b64encode
+from collections.abc import Mapping
 from io import BytesIO
-from typing import Any, ClassVar, Mapping
+from typing import Any, ClassVar
 
 import numpy as np
 import param
@@ -89,7 +90,7 @@ class _MediaBase(ModelPane):
             return True
         return False
 
-    def _to_np_int16(self, data: np.ndarray):
+    def _to_np_int16(self, data: np.ndarray) -> np.ndarray:
         dtype = data.dtype
 
         if dtype in (np.float32, np.float64):
@@ -97,10 +98,12 @@ class _MediaBase(ModelPane):
 
         return data
 
-    def _to_buffer(self, data: np.ndarray|TensorLike):
-        if isinstance(data, TensorLike):
-            data = data.numpy()
-        data = self._to_np_int16(data)
+    def _to_buffer(self, data: np.ndarray | TensorLike):
+        if isinstance(data, np.ndarray):
+            values = data
+        elif isinstance(data, TensorLike):
+            values = data.numpy()
+        data = self._to_np_int16(values)
 
         from scipy.io import wavfile
         buffer = BytesIO()
