@@ -12,6 +12,7 @@ from typing import (
     TYPE_CHECKING, Any, ClassVar, TypeVar,
 )
 
+import numpy as np
 import param  # type: ignore
 
 from bokeh.models import ImportedStyleSheet, Tooltip
@@ -21,6 +22,7 @@ from param.parameterized import register_reference_transform
 from .._param import Margin
 from ..layout.base import Row
 from ..reactive import Reactive
+from ..util import unique_iterator
 from ..viewable import Layoutable, Viewable
 
 if TYPE_CHECKING:
@@ -69,6 +71,45 @@ class WidgetBase(param.Parameterized):
         )
         return layout[0]
 
+    @classmethod
+    def _infer_params(cls, values, **params):
+        if 'name' not in params and getattr(values, 'name', None):
+            params['name'] = values.name
+        if 'start' in cls.param and 'start' not in params:
+            params['start'] = np.nanmin(values)
+        if 'end' in cls.param and 'end' not in params:
+            params['end'] = np.nanmax(values)
+        if 'options' in cls.param and 'options' not in params:
+            if isinstance(values, dict):
+                params['options'] = values
+            else:
+                params['options'] = list(unique_iterator(values))
+        if 'value' not in params:
+            p = cls.param['value']
+            if isinstance(p, param.Tuple):
+                params['value'] = (params['start'], params['end'])
+            elif 'start' in params:
+                params['value'] = params['start']
+            elif ('options' in params and not isinstance(p, (param.List, param.ListSelector))
+                  and not getattr(cls, '_allows_none', False)):
+                params['value'] = params['options'][0]
+        return params
+
+    @classmethod
+    def from_values(cls, values, **params):
+        """
+        Creates an instance of this Widget where the parameters are
+        inferred from the data.
+
+        Parameters
+        ----------
+        values: Iterable
+            The values to infer the parameters from.
+        params: dict
+            Additional parameters to pass to the widget.
+        """
+        return cls(**cls._infer_params(values, **params))
+
     @property
     def rx(self):
         return self.param.value.rx
@@ -83,7 +124,7 @@ class Widget(Reactive, WidgetBase):
     disabled = param.Boolean(default=False, doc="""
        Whether the widget is disabled.""")
 
-    name = param.String(default='')
+    name = param.String(default='', constant=False)
 
     height = param.Integer(default=None, bounds=(0, None))
 
@@ -134,7 +175,7 @@ class Widget(Reactive, WidgetBase):
             renderer_options = params.pop("renderer_options", {})
             if isinstance(description, str):
                 from ..pane.markup import Markdown
-                parser = Markdown._get_parser('markdown-it', (), **renderer_options)
+                parser = Markdown._get_parser('markdown-it', (), Markdown.hard_line_break, **renderer_options)
                 html = parser.render(description)
                 params['description'] = Tooltip(
                     content=HTML(html), position='right',
@@ -166,8 +207,8 @@ class Widget(Reactive, WidgetBase):
         Returns the bokeh model and a discrete set of value states
         for the widget.
 
-        Arguments
-        ---------
+        Parameters
+        ----------
         root: bokeh.model.Model
           The root model of the widget
         values: list (optional)
@@ -206,6 +247,7 @@ class CompositeWidget(Widget):
     __abstract = True
 
     def __init__(self, **params):
+        self._composite = self._composite_type()
         super().__init__(**params)
         layout_params = [p for p in Layoutable.param if p != 'name']
         layout = {p: getattr(self, p) for p in layout_params
@@ -216,7 +258,7 @@ class CompositeWidget(Widget):
             min_width = layout.pop('width')
             if not layout.get('min_width'):
                 layout['min_width'] = min_width
-        self._composite = self._composite_type(**layout)
+        self._composite.param.update(**layout)
         self._models = self._composite._models
         self._internal_callbacks.append(
             self.param.watch(self._update_layout_params, layout_params)
@@ -233,8 +275,8 @@ class CompositeWidget(Widget):
         Iterates over the Viewable and any potential children in the
         applying the Selector.
 
-        Arguments
-        ---------
+        Parameters
+        ----------
         selector: type or callable or None
           The selector allows selecting a subset of Viewables by
           declaring a type or callable function to filter by.
